@@ -296,8 +296,7 @@ void build_widgets()
    ch * adjust_HSL_tip = "Adjust color using HSL colors";
    ch * color_profile_tip = "Convert image to another color profile";
    ch * remove_dust_tip = "Remove dust spots from old scanned photos";
-   ch * chromatic1_tip = "Fix color fringes in outer areas of an image";
-   ch * chromatic2_tip = "Fix color fringes on dark/bright feature edges";
+   ch * chromatic_tip = "Fix color fringes in outer areas of an image";
 
    //  refine menu
    ch * voodoo1_tip = "1-click auto improve that may be good enough";
@@ -324,6 +323,7 @@ void build_widgets()
    ch * texture_tip = "Add texture to an image";
    ch * pattern_tip = "Tile image with a repeating pattern";
    ch * dither_tip = "Convert image into dithered dots";
+   ch * blobs_tip = "Pixels aggregate and condense into blobs";
    ch * engrave_tip = "Convet image into black/white lines";
    ch * mosaic_tip = "Create a mosaic with tiles made from all images";
    ch * add_noise_tip = "Add random noise to an image";
@@ -394,7 +394,6 @@ void build_widgets()
    ch * duplicates_tip = "Search all image files and report duplicates";
    ch * measure_image_tip = "Measure distances within an image";
    ch * show_RGB_tip = "Show RGB colors at mouse position";
-   ch * popup_text_tip = "Show text strings for edit insertion";
    ch * calib_printer_tip = "Calibrate printer colors";
    ch * grid_settings_tip = "Set grid line counts or spacing";
    ch * toggle_grid_tip = "Toggle grid lines on and off";
@@ -406,14 +405,12 @@ void build_widgets()
    //  help menu
    ch * user_guide_tip = "Read or search the user guide";
    ch * video_tutorial_tip = "Fotoxx video tutorial on YouTube";
-   ch * all_edit_funcs_tip = "Overview of all Fotoxx edit functions";
    ch * outboard_programs_tip = "List outboard programs and functions";
    ch * logfile_tip = "View the log file (info and error messages)";
    ch * command_params_tip = "List Fotoxx command line parameters";
    ch * changelog_tip = "Show Fotoxx changes for recent releases";
    ch * copyright_tip = "Fotoxx copyright notice";
    ch * licenses_tip = "Licenses used by Fotoxx: GNU and Pareto";
-   ch * source_build_tip = "How to build Fotoxx from source";
    ch * privacy_tip = "Fotoxx privacy policy";
    ch * about_tip = "Show Fotoxx installed version and author contact";
    ch * homepage_tip = "Fotoxx web site (information and downloads)";
@@ -548,8 +545,7 @@ void build_widgets()
    MENU(mRepair,     "Adjust HSL", 0,         adjust_HSL_tip,               m_adjust_HSL, 0 );
    MENU(mRepair,     "Color Profile", 0,      color_profile_tip,            m_color_profile, 0 );
    MENU(mRepair,     "Remove Dust", 0,        remove_dust_tip,              m_remove_dust, 0 );
-   MENU(mRepair,     "Chromatic 1", 0,        chromatic1_tip,               m_chromatic1, 0 );
-   MENU(mRepair,     "Chromatic 2", 0,        chromatic2_tip,               m_chromatic2, 0 );
+   MENU(mRepair,     "Chromatic", 0,          chromatic_tip,                m_chromatic, 0 );
 
    mRefine = create_popmenu();
    MENU(mRefine,     "Voodoo 1", 0,              voodoo1_tip,               m_voodoo1, 0 );
@@ -577,6 +573,7 @@ void build_widgets()
    MENU(mEffects,    "Texture", 0,               texture_tip,               m_texture, 0 );
    MENU(mEffects,    "Pattern", 0,               pattern_tip,               m_pattern, 0 );
    MENU(mEffects,    "Dither", 0,                dither_tip,                m_dither, 0 );
+   MENU(mEffects,    "Blobs", 0,                 blobs_tip,                 m_blobs, 0 );
    MENU(mEffects,    "Engrave", 0,               engrave_tip,               m_engrave, 0 );
    MENU(mEffects,    "Mosaic", 0,                mosaic_tip,                m_mosaic, 0 );
    MENU(mEffects,    "Add Noise", 0,             add_noise_tip,             m_add_noise, 0 );
@@ -647,7 +644,6 @@ void build_widgets()
    MENU(mTools,   "Find Duplicates", 0,          duplicates_tip,            m_duplicates, 0 );
    MENU(mTools,   "Measure Image", 0,            measure_image_tip,         m_measure_image, 0 );
    MENU(mTools,   "Show RGB", 0,                 show_RGB_tip,              m_show_RGB, 0 );
-   MENU(mTools,   "Popup Text", 0,               popup_text_tip,            m_popup_text, 0 );
    MENU(mTools,   "Calibrate Printer", 0,        calib_printer_tip,         m_calibrate_printer, 0 );
    MENU(mTools,   "Grid Settings", 0,            grid_settings_tip,         m_grid_settings, 0 );
    MENU(mTools,   "Toggle_Grid", 0,              toggle_grid_tip,           m_toggle_grid, 0 );
@@ -659,14 +655,12 @@ void build_widgets()
    mHelp = create_popmenu();
    MENU(mHelp,    "User Guide", 0,               user_guide_tip,            m_help, 0 );
    MENU(mHelp,    "Video Tutorial", 0,           video_tutorial_tip,        m_help, 0 );
-   MENU(mHelp,    "All Edit Funcs", 0,           all_edit_funcs_tip,        m_help, 0 );
    MENU(mHelp,    "Outboard Programs", 0,        outboard_programs_tip,     m_help, 0 );
    MENU(mHelp,    "Log File", 0,                 logfile_tip,               m_help, 0 );
    MENU(mHelp,    "Command Params", 0,           command_params_tip,        m_help, 0 );
    MENU(mHelp,    "Changelog", 0,                changelog_tip,             m_help, 0 );
    MENU(mHelp,    "Copyright", 0,                copyright_tip,             m_help, 0 );
    MENU(mHelp,    "Licenses", 0,                 licenses_tip,              m_help, 0 );
-   MENU(mHelp,    "Source Build", 0,             source_build_tip,          m_help, 0 );
    MENU(mHelp,    "Privacy", 0,                  privacy_tip,               m_help, 0 );
    MENU(mHelp,    "About Fotoxx", 0,             about_tip,                 m_help, 0 );
    MENU(mHelp,    "Home Page", 0,                homepage_tip,              m_help, 0 );
@@ -820,7 +814,6 @@ void build_widgets()
    KBshort("Open Image File",    m_open_file,               0     );
    KBshort("Permissions",        m_permissions,             0     );
    KBshort("Places/Dates",       m_meta_places_dates,       0     );
-   KBshort("Popup Text",         m_popup_text,              0     );
    KBshort("Settings",           m_settings,                0     );
    KBshort("Print Calibrated",   m_print_calibrated,        0     );
    KBshort("Print",              m_print,                   0     );
